**********************
Command Line Interface
**********************

These examples are for development in a virtual environment

Commands
========

Run
--------

python badwing run


Development
-----------

python badwing dev sandbox
